==> netxms-3.9.280.tar.gz: netxms-3.9.280/src/libnxjava/java/src/main/java/org/netxms/bridge/Platform.java <==
/**
 * NetXMS Java Bridge
 * Copyright (C) 2013 TEMPEST a.s.
 * Copyright (C) 2014-2017 Raden Solutions
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.bridge;

/**
 * Platform utility class
 */
public final class Platform
{
   /**
    * Get NetXMS directory (internal bridge to native code)
    * 
    * @param type directory type
    * @return path to directory or empty string on error
    */
   protected static native String getNetXMSDirectoryInternal(int type);

   /**
    * Write log message using NetXMS logging facility
    * 
    * @param level log level
    * @param message message
    */
   protected static native void writeLog(int level, String message);

   /**
    * Write debug log message using NetXMS logging facility
    * 
    * @param level debug level (0-9)
    * @param message message
    */
   public static void writeDebugLog(int level, String message)
   {
      writeDebugLog(null,  level, message);
   }

   /**
    * Write debug log message using NetXMS logging facility
    * 
    * @param tag debug tag
    * @param level debug level (0-9)
    * @param message message
    */
   public static native void writeDebugLog(String tag, int level, String message);

   /**
    * Wrapper for native writeLog call
    * 
    * @param level log level
    * @param message message text
    */
   public static void writeLog(LogLevel level, String message)
   {
      writeLog(level.getValue(), message);
   }

   /**
    * Write exception's stack trace to debug log
    * 
    * @param level log level
    * @param prefix message prefix
    * @param e exception to log
    */
   public static void writeDebugLog(int level, String prefix, Throwable e)
   {
      writeDebugLog(null, level, prefix, e);
   }
   
   /**
    * Write exception's stack trace to debug log
    * 
    * @param tag debug tag
    * @param level log level
    * @param prefix message prefix
    * @param e exception to log
    */
   public static void writeDebugLog(String tag, int level, String prefix, Throwable e)
   {
      for(StackTraceElement s : e.getStackTrace())
      {
         writeDebugLog(tag, level, prefix + s.toString());
      }
      if (e.getCause() != null)
      {
         writeDebugLog(tag, level, prefix.trim() + " Caused by: " + e.getCause().getClass().getCanonicalName() + ": " + e.getCause().getMessage());
         writeDebugLog(tag, level, prefix, e.getCause());
      }
   }
   
   /**
    * Get NetXMS directory
    * 
    * @param type directory type
    * @return path to directory or empty string on error
    */
   public static String getNetXMSDirectory(DirectoryType type)
   {
      return getNetXMSDirectoryInternal(type.getValue());
   }
}

==> netxms-5.0.0.tar.gz: netxms-5.0.0/src/libnxjava/java/src/main/java/org/netxms/bridge/Platform.java <==
/**
 * NetXMS Java Bridge
 * Copyright (C) 2013 TEMPEST a.s.
 * Copyright (C) 2014-2017 Raden Solutions
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.bridge;

/**
 * Platform utility class
 */
public final class Platform
{
   /**
    * Get NetXMS directory (internal bridge to native code)
    * 
    * @param type directory type
    * @return path to directory or empty string on error
    */
   protected static native String getNetXMSDirectoryInternal(int type);

   /**
    * Get NetXMS directory
    * 
    * @param type directory type
    * @return path to directory or empty string on error
    */
   public static String getNetXMSDirectory(DirectoryType type)
   {
      return getNetXMSDirectoryInternal(type.getValue());
   }

   /**
    * Write log message using NetXMS logging facility
    * 
    * @param tag debug tag
    * @param level log level
    * @param message message
    */
   protected static native void writeLog(String tag, int level, String message);

   /**
    * Wrapper for native writeLog call
    * 
    * @param level log level
    * @param message message text
    * @deprecated use <code>writeLog(String tag, LogLevel level, String message)</code> instead
    */
   @Deprecated
   public static void writeLog(LogLevel level, String message)
   {
      writeLog(null, level.getValue(), message);
   }

   /**
    * Wrapper for native writeLog call
    * 
    * @param tag debug tag
    * @param level log level
    * @param message message text
    */
   public static void writeLog(String tag, LogLevel level, String message)
   {
      writeLog(tag, level.getValue(), message);
   }

   /**
    * Write debug log message using NetXMS logging facility
    * 
    * @param tag debug tag
    * @param level debug level (0-9)
    * @param message message
    */
   public static native void writeDebugLog(String tag, int level, String message);

   /**
    * Write debug log message using NetXMS logging facility
    * 
    * @param level debug level (0-9)
    * @param message message
    * @deprecated use <code>writeDebugLog(String tag, LogLevel level, String message)</code> instead
    */
   @Deprecated
   public static void writeDebugLog(int level, String message)
   {
      writeDebugLog(null, level, message);
   }

   /**
    * Write exception's stack trace to debug log
    * 
    * @param level log level
    * @param prefix message prefix
    * @param e exception to log
    * @deprecated use <code>writeDebugLog(String tag, int level, String prefix, Throwable e)</code> instead
    */
   @Deprecated
   public static void writeDebugLog(int level, String prefix, Throwable e)
   {
      writeDebugLog(null, level, prefix, e);
   }

   /**
    * Write exception's stack trace to debug log
    * 
    * @param tag debug tag
    * @param level log level
    * @param prefix message prefix
    * @param e exception to log
    */
   public static void writeDebugLog(String tag, int level, String prefix, Throwable e)
   {
      for(StackTraceElement s : e.getStackTrace())
      {
         writeDebugLog(tag, level, prefix + s.toString());
      }
      if (e.getCause() != null)
      {
         writeDebugLog(tag, level, prefix.trim() + " Caused by: " + e.getCause().getClass().getCanonicalName() + ": " + e.getCause().getMessage());
         writeDebugLog(tag, level, prefix, e.getCause());
      }
   }
}
